@@ -1,12 +1,13 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2018, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * Note to U.S. Government Users Restricted Rights:
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
- *******************************************************************************/
+ ****************************************************************************** */
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 'use strict'
 
 import _ from 'lodash'
@@ -15,8 +16,8 @@ import React from 'react'
 import PropTypes from 'prop-types'
 import classNames from 'classnames'
 import { Scrollbars } from 'react-custom-scrollbars'
-import { NumberInput, MultiSelect, Button } from 'carbon-components-react'
 import { TimesIcon } from '@patternfly/react-icons'
+import { Spinner } from '@patternfly/react-core'
 import jsYaml from 'js-yaml'
 import '../../../../graphics/diagramShapes.svg'
 import '../../../../graphics/diagramIcons.svg'
@@ -24,6 +25,7 @@ import msgs from '../../../../nls/platform.properties'
 import { createResourceSearchLink } from '../utils/diagram-helpers'
 import { getLegendTitle } from './defaults/titles'
 import ClusterDetailsContainer from './ClusterDetailsContainer'
+import ArgoAppDetailsContainer from './ArgoAppDetailsContainer'
 
 const DetailsViewDecorator = ({ shape, className }) => {
   return (
@@ -46,22 +48,36 @@ DetailsViewDecorator.propTypes = {
 class DetailsView extends React.Component {
   constructor(props) {
     super(props)
+    this.toggleLinkLoading = this.toggleLinkLoading.bind(this)
+
+    this.state = {
+      isLoading: false,
+      linkID: ''
+    }
   }
 
   handleClick(value) {
+    this.setState({ linkID: value.id })
     this.processActionLink(value)
   }
 
   handleKeyPress(value, e) {
     if (e.key === 'Enter') {
+      this.setState({ linkID: value.id })
       this.processActionLink(value)
     }
   }
 
+  toggleLinkLoading() {
+    this.setState(prevState => ({
+      isLoading: !prevState.isLoading
+    }))
+  }
+
   processActionLink(value) {
     const { processActionLink } = this.props
     const { data } = value
-    processActionLink(data)
+    processActionLink(data, this.toggleLinkLoading)
   }
 
   render() {
@@ -129,17 +145,13 @@ class DetailsView extends React.Component {
     case 'spacer':
       return this.renderSpacer()
     case 'link':
-      return this.renderLink(detail, true)
-    case 'number':
-      return this.renderNumber(detail, locale)
-    case 'selector':
-      return this.renderSelector(detail, locale)
-    case 'submit':
-      return this.renderSubmit(detail, locale)
+      return this.renderLink(detail, true, locale)
     case 'snippet':
       return this.renderSnippet(detail, locale)
     case 'clusterdetailcombobox':
       return this.renderClusterDetailComboBox(detail, locale)
+    case 'relatedargoappdetails':
+      return this.renderRelatedArgoAppDetails(detail, locale)
     default:
       return this.renderLabel(detail, locale)
     }
@@ -214,20 +226,25 @@ class DetailsView extends React.Component {
     return null
   }
 
-  renderLink({ value, indent }) {
+  renderLink({ value, indent, locale }) {
     if (!value) {
       return <div />
     }
+    const { isLoading, linkID } = this.state
+    const loadingArgoLink = isLoading && value.id === linkID
     const handleClick = this.handleClick.bind(this, value)
     const handleKeyPress = this.handleKeyPress.bind(this, value)
     const showLaunchOutIcon = !R.pathOr(false, ['data', 'specs', 'isDesign'])(
       value
     ) //if not show yaml
+    const isExternal =
+      _.get(value, 'data.action', '') !== 'show_search' &&
+      _.get(value, 'data.action', '') !== 'show_resource_yaml'
+
+    const label = value.labelKey
+      ? msgs.get(value.labelKey, locale)
+      : value.label
 
-    let iconName = 'arrowRight'
-    if (_.get(value, 'data.targetLink', '').startsWith('http')) {
-      iconName = 'carbonLaunch'
-    }
     const mainSectionClasses = classNames({
       sectionContent: true,
       borderLeft: indent ? true : false
@@ -241,78 +258,43 @@ class DetailsView extends React.Component {
     return (
       <div className={mainSectionClasses} key={Math.random()}>
         <span
-          className={linkLabelClasses}
+          className={`${linkLabelClasses} ${
+            loadingArgoLink ? 'loadingLink' : ''
+          }`}
           id="linkForNodeAction"
           tabIndex="0"
           role={'button'}
           onClick={handleClick}
           onKeyPress={handleKeyPress}
         >
-          {value.label}
-          {showLaunchOutIcon && (
-            <svg width="11px" height="8px" style={{ marginLeft: '9px' }}>
-              <use href={`#diagramIcons_${iconName}`} className="label-icon" />
-            </svg>
-          )}
+          {loadingArgoLink && <Spinner size="sm" />}
+          {label}
+          {showLaunchOutIcon &&
+            (isExternal ? (
+              <svg
+                width="12px"
+                height="12px"
+                style={{ marginLeft: '8px', stroke: '#0066CC' }}
+              >
+                <use href="#diagramIcons_carbonLaunch" className="label-icon" />
+              </svg>
+            ) : (
+              <svg
+                width="12px"
+                height="12px"
+                style={{ marginLeft: '8px', stroke: '#0066CC' }}
+              >
+                <use href="#diagramIcons_open-new-tab" className="label-icon" />
+              </svg>
+            ))}
         </span>
       </div>
     )
   }
 
-  renderNumber({ labelKey, value }, locale) {
-    return (
-      <div className="sectionContent form" key={Math.random()}>
-        {labelKey && (
-          <span className="label">{msgs.get(labelKey, locale)}: </span>
-        )}
-        <NumberInput
-          id={labelKey}
-          label={''}
-          value={value}
-          min={1}
-          max={10}
-          step={1}
-          onChange={this.enableSubmitBtn.bind(this)}
-        />
-      </div>
-    )
-  }
-
-  renderSelector({ labelKey, value, other }, locale) {
-    return (
-      <div className="sectionContent form" key={Math.random()}>
-        {labelKey && (
-          <span className="label">{msgs.get(labelKey, locale)}: </span>
-        )}
-        <MultiSelect.Filterable
-          items={other}
-          initialSelectedItems={value}
-          placeholder={value.join(', ')}
-          itemToString={item => item}
-          onChange={this.enableSubmitBtn.bind(this)}
-        />
-      </div>
-    )
-  }
-
   setSubmitBtn = ref => {
     this.submitBtn = ref
   };
-  renderSubmit() {
-    return (
-      <div className="sectionContent submit" key={Math.random()}>
-        <Button
-          small
-          id="edit-button"
-          disabled
-          ref={this.setSubmitBtn}
-          onClick={this.onSubmit}
-        >
-          {msgs.get('modal.button.submit', this.props.locale)}
-        </Button>
-      </div>
-    )
-  }
 
   enableSubmitBtn() {
     this.submitBtn.disabled = false
@@ -353,6 +335,8 @@ class DetailsView extends React.Component {
       <div className="sectionContent" key={Math.random()}>
         <ClusterDetailsContainer
           clusterList={comboboxdata.clusterList}
+          sortedClusterNames={comboboxdata.sortedClusterNames}
+          searchClusters={comboboxdata.searchClusters}
           clusterID={comboboxdata.clusterID}
           locale={locale}
           clusterDetailsContainerControl={clusterDetailsContainerControl}
@@ -360,10 +344,28 @@ class DetailsView extends React.Component {
       </div>
     )
   }
+
+  renderRelatedArgoAppDetails({ relatedargoappsdata }, locale) {
+    const { argoAppDetailsContainerControl } = this.props
+    return (
+      <div className="sectionContent" key={Math.random()}>
+        <ArgoAppDetailsContainer
+          argoAppList={relatedargoappsdata.argoAppList}
+          locale={locale}
+          argoAppDetailsContainerControl={argoAppDetailsContainerControl}
+        />
+      </div>
+    )
+  }
 }
 
 DetailsView.propTypes = {
   activeFilters: PropTypes.object,
+  argoAppDetailsContainerControl: PropTypes.shape({
+    argoAppDetailsContainerData: PropTypes.object,
+    handleArgoAppDetailsContainerUpdate: PropTypes.func,
+    handleErrorMsg: PropTypes.func
+  }),
   clusterDetailsContainerControl: PropTypes.shape({
     clusterDetailsContainerData: PropTypes.object,
     handleClusterDetailsContainerUpdate: PropTypes.func
