@@ -2,7 +2,8 @@ import * as React from 'react';
 import styles from '@patternfly/react-styles/css/components/FormControl/form-control';
 import { css } from '@patternfly/react-styles';
 import { ValidatedOptions } from '../../helpers/constants';
-import { debounce, trimLeft } from '../../helpers/util';
+import { debounce, trimLeft, canUseDOM } from '../../helpers/util';
+import { getDefaultOUIAId, getOUIAProps, OUIAProps } from '../../helpers';
 
 export enum TextInputTypes {
   text = 'text',
@@ -19,7 +20,8 @@ export enum TextInputTypes {
 }
 
 export interface TextInputProps
-  extends Omit<React.HTMLProps<HTMLInputElement>, 'onChange' | 'onFocus' | 'onBlur' | 'disabled' | 'ref'> {
+  extends Omit<React.HTMLProps<HTMLInputElement>, 'onChange' | 'onFocus' | 'onBlur' | 'disabled' | 'ref'>,
+    OUIAProps {
   /** Additional classes added to the TextInput. */
   className?: string;
   /** Flag to show if the input is disabled. */
@@ -61,14 +63,18 @@ export interface TextInputProps
   /** Callback function when input is blurred (focus leaves) */
   onBlur?: (event?: any) => void;
   /** icon variant */
-  iconVariant?: 'calendar' | 'clock';
+  iconVariant?: 'calendar' | 'clock' | 'search';
   /** Custom icon url to set as the input's background-image */
   customIconUrl?: string;
   /** Dimensions for the custom icon set as the input's background-size */
   customIconDimensions?: string;
 }
 
-export class TextInputBase extends React.Component<TextInputProps> {
+interface TextInputState {
+  ouiaStateId: string;
+}
+
+export class TextInputBase extends React.Component<TextInputProps, TextInputState> {
   static displayName = 'TextInputBase';
   static defaultProps: TextInputProps = {
     'aria-label': null,
@@ -79,7 +85,8 @@ export class TextInputBase extends React.Component<TextInputProps> {
     isReadOnly: false,
     type: TextInputTypes.text,
     isLeftTruncated: false,
-    onChange: (): any => undefined
+    onChange: (): any => undefined,
+    ouiaSafe: true
   };
   inputRef = React.createRef<HTMLInputElement>();
 
@@ -89,6 +96,9 @@ export class TextInputBase extends React.Component<TextInputProps> {
       // eslint-disable-next-line no-console
       console.error('Text input:', 'Text input requires either an id or aria-label to be specified');
     }
+    this.state = {
+      ouiaStateId: getDefaultOUIAId(TextInputBase.displayName)
+    };
   }
 
   handleChange = (event: React.FormEvent<HTMLInputElement>) => {
@@ -100,13 +110,17 @@ export class TextInputBase extends React.Component<TextInputProps> {
   componentDidMount() {
     if (this.props.isLeftTruncated) {
       this.handleResize();
-      window.addEventListener('resize', debounce(this.handleResize, 250));
+      if (canUseDOM) {
+        window.addEventListener('resize', debounce(this.handleResize, 250));
+      }
     }
   }
 
   componentWillUnmount() {
     if (this.props.isLeftTruncated) {
-      window.removeEventListener('resize', debounce(this.handleResize, 250));
+      if (canUseDOM) {
+        window.removeEventListener('resize', debounce(this.handleResize, 250));
+      }
     }
   }
 
@@ -160,6 +174,8 @@ export class TextInputBase extends React.Component<TextInputProps> {
       iconVariant,
       customIconUrl,
       customIconDimensions,
+      ouiaId,
+      ouiaSafe,
       ...props
     } = this.props;
 
@@ -180,19 +196,20 @@ export class TextInputBase extends React.Component<TextInputProps> {
           styles.formControl,
           validated === ValidatedOptions.success && styles.modifiers.success,
           validated === ValidatedOptions.warning && styles.modifiers.warning,
-          (iconVariant || customIconUrl) && styles.modifiers.icon,
+          ((iconVariant && iconVariant !== 'search') || customIconUrl) && styles.modifiers.icon,
           iconVariant && styles.modifiers[iconVariant],
           className
         )}
         onChange={this.handleChange}
         type={type}
         value={value}
-        aria-invalid={validated === ValidatedOptions.error}
+        aria-invalid={props['aria-invalid'] ? props['aria-invalid'] : validated === ValidatedOptions.error}
         required={isRequired}
         disabled={isDisabled}
         readOnly={isReadOnly}
         ref={innerRef || this.inputRef}
         {...((customIconUrl || customIconDimensions) && { style: customIconStyle })}
+        {...getOUIAProps(TextInput.displayName, ouiaId !== undefined ? ouiaId : this.state.ouiaStateId, ouiaSafe)}
       />
     );
   }
